@@ -235,7 +235,7 @@ class JupyterCommand(Command):
             proc = await asyncio.create_subprocess_exec(
                 *cmd,
                 cwd=job.output_directory,
-                env=environment,
+                env={**os.environ, **environment},
                 stdin=stdin,
                 stdout=stdout,
                 stderr=stderr)
